/*****************************************************************************
 *                                                                           *
 *        **********                                                         *
 *       ************                                                        *
 *      ***        ***                                                       *
 *      ***   +++   ***                                                      *
 *      ***   + +   ***                                                      *
 *      ***   +                    CHIPCON CC1010 EXAMPLE PROGRAM            *
 *      ***   + +   ***          Simple timer demonstration program          *
 *      ***   +++   ***                                                      *
 *      ***       ***                                                        *
 *       ***********                                                         *
 *        *********                                                          *
 *                                                                           *
 *****************************************************************************
 * This program demonstrates the use of timers.                              *
 *                                                                           *
 * The program uses timer 3 to generate interrupts at variable intervals     *
 * (initially 500 msecs). The interrupt service routine resets the timer and *
 * toggles the red and the yellow LEDs                                       *
 *                                                                           *   
 * Use switch 1 or 2 to increase or decrease the timeout.                    *
 *****************************************************************************
 * Author:              TEL, JOL                                             *
 *****************************************************************************
 * Revision history:                                                         *
 * 1.0  2002/08/29      First Public Release                                 *
 *                                                                           *
 * $Log: timer23.c,v $
 * Revision 1.2  2002/11/19 15:45:21  kht
 * Added startup macros
 *
 * Revision 1.1  2002/10/14 11:17:14  tos
 * Initial version in CVS.
 *
 *                                                                           *
 ****************************************************************************/

#include <chipcon/reg1010.h>
#include <chipcon/cc1010eb.h>
#include <chipcon/hal.h>


ulong timeout;


//----------------------------------------------------------------------------
//  MAIN PROGRAM
//----------------------------------------------------------------------------
void main() {

    // Disable watchdog timer
    WDT_ENABLE(FALSE); 

    // Set optimum settings for speed and low power consumption
    MEM_NO_WAIT_STATES();
    FLASH_SET_POWER_MODE(FLASH_STANDBY_BETWEEN_READS);
    
    // Initialize LEDS
    RLED_OE(TRUE); RLED = LED_OFF;
    YLED_OE(TRUE); YLED = LED_ON;

    // Configure timer 3 to generate an interrupt every 500 msec.
    timeout = 500000;
    halConfigTimer23(TIMER3 | TIMER23_INT_TIMER, timeout, CC1010EB_CLKFREQ);
    TIMER3_RUN(TRUE);

    // Loop forever
    while (TRUE) {
        if (SW1_PRESSED) {
            timeout += 100; 
            halConfigTimer23(TIMER3 | TIMER23_INT_TIMER, timeout, CC1010EB_CLKFREQ);
            TIMER3_RUN(TRUE);
        } else if (SW2_PRESSED) {
        if (timeout>=100)
            timeout -= 100; 
            halConfigTimer23(TIMER3 | TIMER23_INT_TIMER, timeout, CC1010EB_CLKFREQ);
        TIMER3_RUN(TRUE);
        }
    };

} // main

//----------------------------------------------------------------------------
//  Timer 3 interrupt service routine:
//----------------------------------------------------------------------------
void TIMER3_ISR() interrupt INUM_TIMER3 {

    INT_SETFLAG (INUM_TIMER3, INT_CLR);

    // Toggle leds
    RLED = ~RLED;   
    YLED = ~YLED;

} // TIMER3_ISR
